@@ -199,7 +199,15 @@ class TestEval(unittest.TestCase):
             print(s[1])
 
         eval = tfkit.utility.eval_metric.EvalMetric(tokenizer)
-        eval.add_record("input", ['O', 'B_Location', 'I_Location', 'I_Location', 'I_Location', 'I_Location', 'O'], ['O', 'B_Location', 'I_Location', 'B_Location', 'I_Thing', 'I_Location', 'O', 'O'], task='default')
+        eval.add_record("input", ['O', 'B_Location', 'I_Location', 'I_Location', 'I_Location', 'I_Location', 'O'],
+                        ['O', 'B_Location', 'I_Location', 'B_Location', 'I_Thing', 'I_Location', 'O', 'O'],
+                        task='default')
         for s in eval.cal_score('classification'):
             print(s[0])
-            print(s[1])
\ No newline at end of file
+            print(s[1])
+
+        eval = tfkit.utility.eval_metric.EvalMetric(tokenizer)
+        eval.add_record("input", '攝影台', ['攝影台'], task='default')
+        for s in eval.cal_score('classification'):
+            print(s[0])
+            print(s[1])
